[cfe-commits] r44947 - /cfe/trunk/include/clang/Basic/SourceLocation.h

Ted Kremenek kremenek at apple.com
Wed Dec 12 10:32:04 PST 2007


Author: kremenek
Date: Wed Dec 12 12:32:04 2007
New Revision: 44947

URL: http://llvm.org/viewvc/llvm-project?rev=44947&view=rev
Log:
Renamed FullContextSourceLocation to FullSourceLoc.

Modified:
    cfe/trunk/include/clang/Basic/SourceLocation.h

Modified: cfe/trunk/include/clang/Basic/SourceLocation.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Basic/SourceLocation.h?rev=44947&r1=44946&r2=44947&view=diff

==============================================================================
--- cfe/trunk/include/clang/Basic/SourceLocation.h (original)
+++ cfe/trunk/include/clang/Basic/SourceLocation.h Wed Dec 12 12:32:04 2007
@@ -201,21 +201,21 @@
   static SourceRange ReadVal(llvm::Deserializer& D);
 };
   
 /// FullContextSourceLocation - A tuple containing both a SourceLocation
 ///  and its associated SourceManager.  Useful for argument passing to functions
 ///  that expect both objects.
-class FullContextSourceLocation {
+class FullSourceLoc {
   SourceLocation Loc;
   SourceManager* SrcMgr;
 public:
-  explicit FullContextSourceLocation(SourceLocation loc)
+  explicit FullSourceLoc(SourceLocation loc)
     : Loc(loc), SrcMgr(NULL) {}
 
-  explicit FullContextSourceLocation(SourceLocation loc, SourceManager& smgr) 
+  explicit FullSourceLoc(SourceLocation loc, SourceManager& smgr) 
     : Loc(loc), SrcMgr(&smgr) {}
   
-  static FullContextSourceLocation CreateInvalidLocation() {
-    return FullContextSourceLocation(SourceLocation());
+  static FullSourceLoc CreateInvalidLocation() {
+    return FullSourceLoc(SourceLocation());
   }
   
   bool isValid() const { return Loc.isValid(); }
@@ -201,21 +201,21 @@
 };
   
-/// FullContextSourceLocation - A tuple containing both a SourceLocation
+/// FullSourceLoc - A tuple containing both a SourceLocation
 ///  and its associated SourceManager.  Useful for argument passing to functions
 ///  that expect both objects.





More information about the cfe-commits mailing list